@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for VineLinux 5.1's 2.6.27 kernel.
+# This is a kernel build script for VineLinux 4.2's 2.6.16 kernel.
 #
 
 die () {
@@ -10,16 +10,16 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.27-65vl5.src.rpm ]
+if [ ! -r kernel-2.6.16-76.55vl4.src.rpm ]
 then
-    wget http://updates.vinelinux.org/Vine-5.1/updates/SRPMS/kernel-2.6.27-65vl5.src.rpm || die "Can't download source package."
+    wget http://updates.vinelinux.org/Vine-4.2/updates/SRPMS/kernel-2.6.16-76.55vl4.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.27-65vl5.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.16-76.55vl4.src.rpm || die "Can't install source package."
 
 cd /usr/src/vine/SOURCES/ || die "Can't chdir to /usr/src/vine/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.8-20101122.tar.gz ]
+if [ ! -r ccs-patch-1.6.8-20110121.tar.gz ]
 then
-    wget -O ccs-patch-1.6.8-20101122.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.8-20101122.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.6.8-20110121.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.8-20110121.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -27,16 +27,16 @@ cp -p /usr/src/vine/SPECS/kernel-2.6-vl.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
 --- kernel-2.6-vl.spec
 +++ kernel-2.6-vl.spec
-@@ -27,7 +27,7 @@
- %define patchlevel 54
+@@ -23,7 +23,7 @@
+ %define sublevel 16
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
--%define release 65%{?_dist_release}
-+%define release 65%{?_dist_release}_tomoyo_1.6.8p4
+-%define release 76.55%{_dist_release}
++%define release 76.55%{_dist_release}_tomoyo_1.6.8p4
  
  %define make_target bzImage
- %define hdrarch %_target_cpu
-@@ -121,6 +121,9 @@
+ 
+@@ -100,6 +100,9 @@
  # to versions below the minimum
  #
  
@@ -46,27 +46,27 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -153,7 +156,7 @@
+@@ -126,7 +129,7 @@
  #
- %define kernel_prereq  fileutils, module-init-tools >= 3.6, initscripts >= 8.80, mkinitrd >= 5.1.19.6, kernel-firmware >= %{version}
+ %define kernel_prereq  fileutils, modutils >= 3.2.2 , initscripts >= 5.83, mkinitrd >= 4.2.1.8-0vl2.1
  
 -Name: kernel
 +Name: ccs-kernel
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -804,6 +807,10 @@
+@@ -1155,6 +1158,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.8-20101122.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.27-vine-linux-5.1.diff
++tar -zxf %_sourcedir/ccs-patch-1.6.8-20110121.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.16-vine-linux-4.2.diff
 +
  cp %{SOURCE10} Documentation/
  
  # put Vine logo
-@@ -822,6 +829,9 @@
+@@ -1175,6 +1182,9 @@
  for i in *.config
  do 
  	mv $i .config 
